Class: OpenehrRails::ApplicationController
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- OpenehrRails::ApplicationController
- Defined in:
- app/controllers/openehr_rails/application_controller.rb
Direct Known Subclasses
EhrsController, FhirController, OpenehrApi::CompositionsController, OpenehrApi::EhrsController, QueriesController, TemplatesController
Instance Method Summary collapse
-
#openehr_access_scope ⇒ Object
Which engine surface this request targets, so a single OpenehrRails.authenticate_with hook can differentiate if desired: :admin - template management UI, AQL console, patient timeline :rest_api - openEHR REST API under /v1 :fhir - HL7 FHIR R5 facade under /fhir.
Instance Method Details
#openehr_access_scope ⇒ Object
Which engine surface this request targets, so a single OpenehrRails.authenticate_with hook can differentiate if desired:
:admin - template management UI, AQL console, patient timeline
:rest_api - openEHR REST API under /v1
:fhir - HL7 FHIR R5 facade under /fhir
14 15 16 |
# File 'app/controllers/openehr_rails/application_controller.rb', line 14 def openehr_access_scope :admin end |