Exception: OpenehrRails::Aql::UnsupportedFeature
- Defined in:
- lib/openehr_rails/aql/errors.rb
Overview
The query parses but uses a construct the engine cannot execute yet (see OpenehrRails::Aql::QueryValidator for the specific list).
The query parses but uses a construct the engine cannot execute yet (see OpenehrRails::Aql::QueryValidator for the specific list).